#
# spec file for package libmicrohttpd
#
# Copyright (c) 2013 SUSE LINUX Products GmbH, Nuernberg, Germany.
# Copyright (c) 2010,2011,2012  Stephan Kleine
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


%global libmicrohttpd libmicrohttpd10
%global libmicrospdy  libmicrospdy0

Name:           libmicrohttpd
Version:        0.9.30
Release:        4.4
Summary:        Small Embeddable HTTP Server Library
License:        LGPL-2.1+
Group:          Productivity/Networking/Web/Servers
Url:            http://gnunet.org/libmicrohttpd/

Source0:        http://ftpmirror.gnu.org/libmicrohttpd/%{name}-%{version}.tar.gz
Source1:        http://ftpmirror.gnu.org/libmicrohttpd/%{name}-%{version}.tar.gz.sig
Source2:        libmicrohttpd.keyring
#PATCH-FIX-OPENSUSE: test_tls_options fails when running in OBS, so lets drop that one
Patch0:         libmicrohttpd-drop-test_tls_options.patch
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
BuildRequires:  libcurl-devel
BuildRequires:  libgcrypt-devel >= 1.2.4
BuildRequires:  libtasn1-devel
%if 0%{?suse_version}
BuildRequires:  libgnutls-devel
BuildRequires:  libopenssl-devel
BuildRequires:  pkg-config
%if 0%{?suse_version} >= 1230
BuildRequires:  gpg-offline
%endif
%else
BuildRequires:  gnutls-devel
BuildRequires:  pkgconfig
%endif

%description
GNU libmicrohttpd is a small C library that is supposed to make it easy to run 
an HTTP server as part of another application. GNU libmicrohttpd is free software 
and part of the GNU project. Key features that distinguish libmicrohttpd from 
other projects are:

    * C library: fast and small
    * API is simple, expressive and fully reentrant
    * Implementation is http 1.1 compliant
    * HTTP server can listen on multiple ports
    * Support for IPv6
    * Support for incremental processing of POST data
    * Creates binary of only 30k (without TLS/SSL support)
    * Three different threading models
    * Supported platforms include GNU/Linux, FreeBSD, OpenBSD, NetBSD, OS X, W32, 
      Symbian and z/OS
    * Optional support for SSL3 and TLS (requires libgcrypt)

libmicrohttpd was started because the author needed an easy way to add a concurrent 
HTTP server to other projects. Existing alternatives were either non-free, not 
reentrant, standalone, of terrible code quality or a combination thereof. Do not 
use libmicrohttpd if you are looking for a standalone http server, there are many 
other projects out there that provide that kind of functionality already. However, 
if you want to be able to serve simple WWW pages from within your C or C++ 
application, check it out.

%package -n %{libmicrohttpd}

Summary:        Small embeddable http server library
Group:          System/libraries

%description -n %{libmicrohttpd}
Shared library for %{name} (%{summary}).

%package -n %{libmicrospdy}

Summary:        Small embeddable http server library
Group:          System/libraries

%description -n %{libmicrospdy}
Shared library for libmicrospdy (%{summary}).

WARNING: Additionally, a second, still very experimental library is provided
for SPDY (the base for HTTP 2.0) support.  libmicrospdy provides a compact API
and implementation of SPDY server. libmicrospdy currently only implements
partially version 3 of SPDY.

%package devel
Requires:       %{libmicrohttpd} = %{version}
Requires(post): info
Requires(postun): info
Summary:        Small Embeddable HTTP Server Library
Group:          Development/Libraries/C and C++

%description devel
Headers, pkg-config files, so link and other development files for %{name}
(%{summary}).

%package -n libmicrospdy-devel
Requires:       %{libmicrospdy} = %{version}
Summary:        Small Embeddable HTTP Server Library
Group:          Development/Libraries/C and C++

%description -n libmicrospdy-devel
Headers for libmicrospdy (%{summary}).

%package -n microspdy2http
Summary:        Proxy translated SPDY requests to https server
Group:          System/Libraries

%description -n microspdy2http
Translates incoming SPDY requests to http server on
localhost.
 * Uses libcurl.
 * No error handling for curl requests.

%prep
%if 0%{?suse_version} >= 1230
%gpg_verify %{SOURCE1}
%endif
%setup -q

#XXX: test fail inside OBS only
%if 0%{?opensuse_bs}
%patch0 -p1
%endif

%build
%configure --disable-static \
	--enable-curl
%__make %{?_smp_mflags}

%install
make install DESTDIR="%buildroot"
find %{buildroot} -name "*.la" -delete

%check
%__make %{?_smp_mflags} check

%post -n %{libmicrohttpd} -p /sbin/ldconfig

%postun -n %{libmicrohttpd} -p /sbin/ldconfig

%post -n %{libmicrospdy} -p /sbin/ldconfig

%postun -n %{libmicrospdy} -p /sbin/ldconfig

%post devel
%if 0%{?fedora_version}
/sbin/install-info --info-dir=%{_infodir} --info-file=%{_infodir}/microhttpd.info%{ext_info}
/sbin/install-info --info-dir=%{_infodir} --info-file=%{_infodir}/microhttpd-tutorial.info%{ext_info}
%endif

%if 0%{?mandriva_version}
%_install_info libmicrohttpd.info
%_install_info libmicrohttpd-tutorial.info
%endif

%if 0%{?suse_version}
%install_info --info-dir=%{_infodir} %{_infodir}/libmicrohttpd.info%{ext_info}
%install_info --info-dir=%{_infodir} %{_infodir}/libmicrohttpd-tutorial.info%{ext_info}
%endif

%postun devel
%if 0%{?fedora_version} || 0%{?scientificlinux_version} || 0%{?centos_version}
/sbin/install-info --delete --info-dir=%{_infodir} --info-file=%{_infodir}/microhttpd.info%{ext_info}
/sbin/install-info --delete --info-dir=%{_infodir} --info-file=%{_infodir}/microhttpd-tutorial.info%{ext_info}
%endif

%if 0%{?mandriva_version}
%_remove_install_info libmicrohttpd.info
%_remove_install_info libmicrohttpd-tutorial.info
%endif

%if 0%{?suse_version}
%install_info_delete --info-dir=%{_infodir} %{_infodir}/libmicrohttpd.info%{ext_info}
%install_info_delete --info-dir=%{_infodir} %{_infodir}/libmicrohttpd-tutorial.info%{ext_info}
%endif

%files -n %{libmicrohttpd}
%defattr(-,root,root)
%{_libdir}/%{name}.so.*

%files devel
%defattr(-,root,root)
%doc ChangeLog
%{_includedir}/microhttpd.h
%{_libdir}/%{name}.so
%{_libdir}/pkgconfig/%{name}.pc
%{_infodir}/%{name}*.info*
%{_mandir}/man3/%{name}.3*

%files -n %{libmicrospdy}
%defattr(-,root,root)
%{_libdir}/libmicrospdy.so.*

%files -n libmicrospdy-devel
%defattr(-,root,root)
%{_includedir}/microspdy.h
%{_libdir}/libmicrospdy.so

%files -n microspdy2http
%defattr(-,root,root)
%attr(0755,root,root) %{_bindir}/microspdy2http

# Do NOT delete this cause I need it for Fedora & Mandriva too!
%if 0%{?fedora_version} || 0%{?scientificlinux_version} || 0%{?centos_version}
%exclude %{_infodir}/dir
%endif

%changelog
* Thu Oct  3 2013 mvyskocil@suse.com
- Update to 0.9.30
  + implements the "SHOULD" clause of RFC 2616 section 8.1.4, which
    may reduce bandwidth consumption when clients cancel requests.
  + fixes build errors with various combinations of operating systems,
    libc versions, and configure flags.
  + fixes a use-after-free crash when using epoll() in combination with
    read errors
  0.9.29:
  + epoll can now also be used with SSL connections
  + following recent HTTP/1.1 clarfications, MHD no longer send
    a "Content-length" header in CONNECT responses.
  + the "MHD_add_connection" call now consistently sets an "errno"
    value to indicate the cause of errors.
    Connections added this way are now always processed immediately.
  + fixes a recently-introduced bug which prevented HTTP pipelining
    from working properly in some cases and a build error in
    conjunction with the "--disable-messages" configure option.
- Enable build of (experimental) SPDY support.
* Wed Jul 24 2013 mvyskocil@suse.com
- Update to 0.9.28
  + support for epoll-based event loops (Linux-only)
  + various new options:
  - MHD_USE_DUAL_STACK for binding to IPv4 and IPv6 at the same time
  - MHD_USE_PIPE_FOR_SHUTDOWN to cleanly support MHD_quiesce_daemon on
    non-Linux systems
  - MHD_CONNECTION_INFO_CONNECTION_FD to allow COMET applications to
    disable TCP Nagle
  - MHD_OPTION_CONNECTION_MEMORY_INCREMENT for better control over
    buffer size allocations
  + and fixes various minor bugs
* Thu Jun  6 2013 mvyskocil@suse.com
- drop test_tls_options if build is in OBS
  libmicrohttpd-drop-test_tls_options.patch
* Wed Jun  5 2013 jengelh@inai.de
- More robust make install call
- Remove redundant %%clean section
- Requires(pre) is useless without a %%pre script
* Thu May 16 2013 mvyskocil@suse.com
- Update to 0.9.27
  + performance improvements for POST processing
  + new API call to reduce the number of select calls (if in "external"
    select mode)
  + new function to allow applications to stop MHD from processing new
    incoming connections while finishing ongoing requests
  + fixes an initialization problem on some platforms
  + fixes bug in the postprocessor's URL parser.
  + SSL connections are no longer dropped if the system uptime is less
    than the connection timeout
  + allows creating responses with zero bytes using
    MHD_create_response_from_callback.
  + few "const" statements have been added to allow keeping more static
    strings in ROM.
  + post processor now tolerates uploads which don't contain "\r\n" and
    also returns keys which don't have a matching value
  + fixes the loss of a parameter in processing POST data from IE8 and
    Chrome. It automatically sets a "Connection: close" header if the
    client requests the connection to be closed. Finally, given both
    'chunked' encoding and 'content-length', MHD now ignores the
    'content-length' header as per the RFC
  + adds support for building libmicrohttpd for Android
  + fixes an issue with data in TLS buffers sometimes not being completely
    drained if there was no activity on the socket.
- reenabled tests and moved to %%check
- add source verification using gpg
* Wed Oct  3 2012 fcrozat@suse.com
- Add copyright header to specfile.
* Fri Sep 28 2012 fcrozat@suse.com
- Update to 0.9.22:
  + Allow to configure basic and digest authentication separately
  + Fix URI argument parsing when string contained keys without
    equals sign in middle of the argument.
  + Reduce default size in poft processor buffer.
- Remove --enable-client-side from configure call, it doesn't exist
  anymore.
- Update License tag to new SPDX format.
* Fri Aug 10 2012 bitshuffler@opensuse.org
- Updated to 0.9.21
* Sun Feb  5 2012 bitshuffler@opensuse.org
- Updated to 0.9.19
* Sun Nov 27 2011 bitshuffler@opensuse.org
- Updated to 0.9.17
* Sat Nov 12 2011 bitshuffler@opensuse.org
- Updated to 0.9.16
* Sun Oct 16 2011 bitshuffler@opensuse.org
- Updated to 0.9.15
* Sat May 21 2011 bitshuffler@opensuse.org
- Updated to 0.9.11
* Fri Apr 29 2011 bitshuffler@opensuse.org
- Updated to 0.9.10
* Wed Mar 30 2011 bitshuffler@opensuse.org
- Updated to 0.9.9
* Sat Mar  5 2011 bitshuffler@opensuse.org
- Updated to 0.9.8
* Tue Feb 15 2011 bitshuffler@opensuse.org
- Updated to 0.9.7
* Thu Jan 27 2011 bitshuffler@opensuse.org
- Updated to 0.9.6
* Sat Jan 15 2011 bitshuffler@opensuse.org
- Updated to 0.9.5
* Wed Dec 29 2010 bitshuffler@opensuse.org
- Updated to 0.9.4
* Wed Nov 24 2010 bitshuffler@opensuse.org
- Updated to 0.9.3
* Thu Oct 21 2010 bitshuffler@opensuse.org
- Updated to 0.9.2
* Mon Sep 20 2010 bitshuffler@opensuse.org
- Updated to 0.9.1
* Tue Jul 27 2010 bitshuffler@opensuse.org
- Updated to 0.9.0
* Mon Mar 15 2010 pascal.bleser@opensuse.org
- update to 0.4.6:
  * fixes use of poll causing busy waiting
  * fixes a segfault if inconsistent options were used
  * fixes SSL support on big-endian architectures
  * fixes an issue with error signalling for PUT/POST requests in HTTP 1.1
* Tue Feb  2 2010 bitshuffler@opensuse.org
- Updated to 0.4.5.
* Sun Jan 17 2010 bitshuffler@opensuse.org
- Initial RPM.
